@@ -1,27 +1,13 @@
-/********************************************************************
-Copyright 2015  Martin Gräßlin <mgraesslin@kde.org>
+/*
+    SPDX-FileCopyrightText: 2015 Martin Gräßlin <mgraesslin@kde.org>
 
-This library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Lesser General Public
-License as published by the Free Software Foundation; either
-version 2.1 of the License, or (at your option) version 3, or any
-later version accepted by the membership of KDE e.V. (or its
-successor approved by the membership of KDE e.V.), which shall
-act as a proxy defined in Section 6 of version 3 of the license.
-
-This library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Lesser General Public License for more details.
-
-You should have received a copy of the GNU Lesser General Public
-License along with this library.  If not, see <http://www.gnu.org/licenses/>.
-*********************************************************************/
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 #ifndef WAYLAND_PLASMAWINDOWMANAGEMENT_H
 #define WAYLAND_PLASMAWINDOWMANAGEMENT_H
 
-#include <QObject>
 #include <QIcon>
+#include <QObject>
 #include <QSize>
 
 #include <KWayland/Client/kwaylandclient_export.h>
@@ -122,8 +108,8 @@ public:
      **/
     EventQueue *eventQueue();
 
-    operator org_kde_plasma_window_management*();
-    operator org_kde_plasma_window_management*() const;
+    operator org_kde_plasma_window_management *();
+    operator org_kde_plasma_window_management *() const;
 
     /**
      * Whether the system is currently showing the desktop.
@@ -156,7 +142,7 @@ public:
      * @returns All windows currently known to the PlasmaWindowManagement
      * @see windowCreated
      **/
-    QList<PlasmaWindow*> windows() const;
+    QList<PlasmaWindow *> windows() const;
     /**
      * @returns The currently active PlasmaWindow, the PlasmaWindow which
      * returns @c true in {@link PlasmaWindow::isActive} or @c nullptr in case
@@ -169,6 +155,23 @@ public:
      **/
     PlasmaWindowModel *createWindowModel();
 
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 73)
+    /**
+     * @returns windows stacking order
+     *
+     * @deprecated Since 5.73, use stackingOrderUuids()
+     */
+    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 73, "Use PlasmaWindow::stackingOrderUuids()")
+    QVector<quint32> stackingOrder() const;
+#endif
+
+    /**
+     * @returns windows stacking order
+     *
+     * @since 5.73
+     */
+    QVector<QByteArray> stackingOrderUuids() const;
+
 Q_SIGNALS:
     /**
      * This signal is emitted right before the interface is released.
@@ -205,6 +208,22 @@ Q_SIGNALS:
      **/
     void removed();
 
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 73)
+    /**
+     * The stacking order changed
+     * @since 5.70
+     * @deprecated Since 5.73, use stackingOrderUuidsChanged()
+     **/
+    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 73, "Use PlasmaWindow::stackingOrderUuidsChanged()")
+    void stackingOrderChanged();
+#endif
+
+    /**
+     * The stacking order uuids changed
+     * @since 5.73
+     **/
+    void stackingOrderUuidsChanged();
+
 private:
     class Private;
     QScopedPointer<Private> d;
@@ -258,8 +277,8 @@ public:
      **/
     bool isValid() const;
 
-    operator org_kde_plasma_window*();
-    operator org_kde_plasma_window*() const;
+    operator org_kde_plasma_window *();
+    operator org_kde_plasma_window *() const;
 
     /**
      * @returns the window title.
@@ -271,11 +290,15 @@ public:
      * @see appIdChanged
      **/
     QString appId() const;
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
     /**
      * @returns the id of the virtual desktop this PlasmaWindow is on
      * @see virtualDesktopChanged
+     * @deprecated: Since 5.52, use plasmaVirtualDesktops instead
      **/
+    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 52, "Use PlasmaWindow::plasmaVirtualDesktops()")
     quint32 virtualDesktop() const;
+#endif
     /**
      * @returns Whether the window is currently the active Window.
      * @see activeChanged
@@ -342,6 +365,11 @@ public:
      * @see skipTaskbarChanged
      **/
     bool skipTaskbar() const;
+    /**
+     * @returns Whether the window should be ignored by a switcher.
+     * @see skipSwitcherChanged
+     **/
+    bool skipSwitcher() const;
     /**
      * @returns The icon of the window.
      * @see iconChanged
@@ -403,10 +431,14 @@ public:
      * @since 5.22
      */
     void requestResize();
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
     /**
      * Requests to send the window to virtual @p desktop.
+     * @deprecated: Since 5.52, use requestEnterVirtualDesktop instead
      **/
+    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 52, "Use PlasmaWindow::requestEnterVirtualDesktop(const QString &)")
     void requestVirtualDesktop(quint32 desktop);
+#endif
 
     /**
      * Requests the window at this model row index have its keep above state toggled.
@@ -449,12 +481,25 @@ public:
      */
     void requestToggleShaded();
 
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 73)
     /**
      * An internal window identifier.
      * This is not a global window identifier.
      * This identifier does not correspond to QWindow::winId in any way.
-     **/
+     *
+     * @deprecated Since 5.73, use uuid(const QString &) instead
+     */
+    KWAYLANDCLIENT_DEPRECATED_VERSION(5, 73, "Use PlasmaWindow::uuid(const QString &)")
     quint32 internalId() const;
+#endif
+
+    /**
+     * A unique identifier for the window
+     *
+     * @see QUuid
+     * @since 5.73
+     */
+    QByteArray uuid() const;
 
     /**
      * The parent window of this PlasmaWindow.
@@ -475,6 +520,82 @@ public:
      **/
     QRect geometry() const;
 
+    /**
+     * Ask the server to make the window enter a virtual desktop.
+     * The server may or may not consent.
+     * A window can enter more than one virtual desktop.
+     *
+     * @since 5.52
+     */
+    void requestEnterVirtualDesktop(const QString &id);
+
+    /**
+     * Make the window enter a new virtual desktop. If the server consents the request,
+     * it will create a new virtual desktop and assign the window to it.
+     * @since 5.52
+     */
+    void requestEnterNewVirtualDesktop();
+
+    /**
+     * Ask the server to make the window the window exit a virtual desktop.
+     * The server may or may not consent.
+     * If it exits all desktops it will be considered on all of them.
+     *
+     * @since 5.52
+     */
+    void requestLeaveVirtualDesktop(const QString &id);
+
+    /**
+     * Return all the virtual desktop ids this window is associated to.
+     * When a desktop gets deleted, it will be automatically removed from this list.
+     * If this list is empty, assume it's on all desktops.
+     *
+     * @since 5.52
+     */
+    QStringList plasmaVirtualDesktops() const;
+
+    /**
+     * Ask the server to make the window enter an activity.
+     * The server may or may not consent.
+     * A window can enter more than one activity.
+     *
+     * @since 5.81
+     */
+    void requestEnterActivity(const QString &id);
+
+    /**
+     * Ask the server to make the window exit an activity.
+     * The server may or may not consent.
+     * If it exits all activities it will be considered on all of them.
+     *
+     * @since 5.81
+     */
+    void requestLeaveActivity(const QString &id);
+
+    /**
+     * Return all the activity ids this window is associated to.
+     * When an activity gets deleted, it will be automatically removed from this list.
+     * If this list is empty, assume it's on all activities.
+     *
+     * @since 5.81
+     */
+    QStringList plasmaActivities() const;
+
+    /**
+     * Return the D-BUS service name for a window's
+     * application menu.
+     *
+     * @since 5.69
+     */
+    QString applicationMenuServiceName() const;
+    /**
+     * Return the D-BUS object path to a windows's
+     * application menu.
+     *
+     * @since 5.69
+     */
+    QString applicationMenuObjectPath() const;
+
 Q_SIGNALS:
     /**
      * The window title changed.
@@ -486,11 +607,17 @@ Q_SIGNALS:
      * @see appId
      **/
     void appIdChanged();
+#if KWAYLANDCLIENT_ENABLE_DEPRECATED_SINCE(5, 52)
     /**
      * The virtual desktop changed.
-     * @see virtualDesktop
+     * @deprecated Since 5.52, use plasmaVirtualDesktopEntered and plasmaVirtualDesktopLeft instead
      **/
+    KWAYLANDCLIENT_DEPRECATED_VERSION(
+        5,
+        52,
+        "Use PlasmaWindow::plasmaVirtualDesktopEntered(const QString &) and PlasmaWindow::plasmaVirtualDesktopLeft(const QString &)")
     void virtualDesktopChanged();
+#endif
     /**
      * The window became active or inactive.
      * @see isActive
@@ -556,6 +683,11 @@ Q_SIGNALS:
      * @see skipTaskbar
      **/
     void skipTaskbarChanged();
+    /**
+     * The skip switcher state changed.
+     * @see skipSwitcher
+     **/
+    void skipSwitcherChanged();
     /**
      * The window icon changed.
      * @see icon
@@ -610,9 +742,47 @@ Q_SIGNALS:
      **/
     void geometryChanged();
 
+    /**
+     * This signal is emitted when the window has entered a new virtual desktop.
+     * The window can be on more than one desktop, or none: then is considered on all of them.
+     * @since 5.46
+     */
+    void plasmaVirtualDesktopEntered(const QString &id);
+
+    /**
+     * This signal is emitted when the window left a virtual desktop.
+     * If the window leaves all desktops, it can be considered on all.
+     *
+     * @since 5.46
+     */
+    void plasmaVirtualDesktopLeft(const QString &id);
+
+    /**
+     * This signal is emitted when the window has entered an activity.
+     * The window can be on more than one activity, or none: then is considered on all of them.
+     * @since 5.81
+     */
+    void plasmaActivityEntered(const QString &id);
+
+    /**
+     * This signal is emitted when the window left an activity.
+     * If the window leaves all activities, it can be considered on all.
+     *
+     * @since 5.81
+     */
+    void plasmaActivityLeft(const QString &id);
+
+    /**
+     *  This signal is emitted when either the D-BUS service name or
+     *  object path for the window's application menu changes.
+     *
+     * @since 5.69
+     **/
+    void applicationMenuChanged();
+
 private:
     friend class PlasmaWindowManagement;
-    explicit PlasmaWindow(PlasmaWindowManagement *parent, org_kde_plasma_window *dataOffer, quint32 internalId);
+    explicit PlasmaWindow(PlasmaWindowManagement *parent, org_kde_plasma_window *dataOffer, quint32 internalId, const char *uuid);
     class Private;
     QScopedPointer<Private> d;
 };
@@ -620,6 +790,6 @@ private:
 }
 }
 
-Q_DECLARE_METATYPE(KWayland::Client::PlasmaWindow*)
+Q_DECLARE_METATYPE(KWayland::Client::PlasmaWindow *)
 
 #endif
