@@ -13,14 +13,12 @@
 #include "global.h"
 #include "resource.h"
 
-class QSize;
 struct wl_resource;
 
 namespace KWayland
 {
 namespace Server
 {
-
 class Display;
 class SurfaceInterface;
 class PlasmaShellSurfaceInterface;
@@ -47,7 +45,7 @@ Q_SIGNALS:
     /**
      * Emitted whenever a PlasmaShellSurfaceInterface got created.
      **/
-    void surfaceCreated(KWayland::Server::PlasmaShellSurfaceInterface*);
+    void surfaceCreated(KWayland::Server::PlasmaShellSurfaceInterface *);
 
 private:
     friend class Display;
@@ -110,7 +108,7 @@ public:
         AlwaysVisible, ///< The panel should be always visible
         AutoHide, ///< The panel auto hides at a screen edge and returns on mouse press against edge
         WindowsCanCover, ///< Windows are allowed to go above the panel, it raises on mouse press against screen edge
-        WindowsGoBelow ///< Window are allowed to go below the panel
+        WindowsGoBelow, ///< Window are allowed to go below the panel
     };
     /**
      * @returns The PanelBehavior for a PlasmaShellSurfaceInterface with role @c Role::Panel
@@ -161,7 +159,7 @@ public:
      * pass focus to the surface.
      * @since 5.28
      **/
-    //TODO KF6 rename to something generic
+    // TODO KF6 rename to something generic
     bool panelTakesFocus() const;
 
     /**
